@@ -15,6 +15,7 @@ import importlib.resources
 from cookiecutter.main import cookiecutter
 from dotenv import load_dotenv
 import subprocess
+from packaging.metadata import Metadata
 
 from .agentstack_data import (
     FrameworkData,
@@ -25,11 +26,13 @@ from .agentstack_data import (
 from agentstack.logger import log
 from agentstack.utils import get_package_path
 from agentstack.tools import get_all_tools
-from agentstack.generation.files import ConfigFile
+from agentstack.generation.files import ConfigFile, ProjectFile
 from agentstack import frameworks
 from agentstack import packaging
 from agentstack import generation
-from agentstack.utils import open_json_file, term_color, is_snake_case
+from agentstack.agents import get_all_agents
+from agentstack.tasks import get_all_tasks
+from agentstack.utils import open_json_file, term_color, is_snake_case, get_framework
 from agentstack.update import AGENTSTACK_PACKAGE
 from agentstack.proj_templates import TemplateConfig
 
@@ -48,6 +51,10 @@ def init_project_builder(
     template: Optional[str] = None,
     use_wizard: bool = False,
 ):
+    if not slug_name and not use_wizard:
+        print(term_color("Project name is required. Use `agentstack init <project_name>`", 'red'))
+        return
+
     if slug_name and not is_snake_case(slug_name):
         print(term_color("Project name must be snake case", 'red'))
         return
@@ -62,13 +69,13 @@ def init_project_builder(
             try:
                 template_data = TemplateConfig.from_url(template)
             except Exception as e:
-                print(term_color(f"Failed to fetch template data from {template}", 'red'))
+                print(term_color(f"Failed to fetch template data from {template}.\n{e}", 'red'))
                 sys.exit(1)
         else:
             try:
                 template_data = TemplateConfig.from_template_name(template)
             except Exception as e:
-                print(term_color(f"Failed to load template {template}", 'red'))
+                print(term_color(f"Failed to load template {template}.\n{e}", 'red'))
                 sys.exit(1)
 
     if template_data:
@@ -81,11 +88,11 @@ def init_project_builder(
         }
         framework = template_data.framework
         design = {
-            'agents': template_data.agents,
-            'tasks': template_data.tasks,
+            'agents': [agent.model_dump() for agent in template_data.agents],
+            'tasks': [task.model_dump() for task in template_data.tasks],
             'inputs': template_data.inputs,
         }
-        tools = template_data.tools
+        tools = [tools.model_dump() for tools in template_data.tools]
 
     elif use_wizard:
         welcome_message()
@@ -97,19 +104,22 @@ def init_project_builder(
 
     else:
         welcome_message()
+        # the user has started a new project; let's give them something to work with
+        default_project = TemplateConfig.from_template_name('hello_alex')
         project_details = {
-            "name": slug_name or "agentstack_project",
+            "name": slug_name or default_project.name,
             "version": "0.0.1",
-            "description": "New agentstack project",
+            "description": default_project.description,
             "author": "Name <Email>",
             "license": "MIT",
         }
-
-        framework = "crewai"  # TODO: if --no-wizard, require a framework flag
-
-        design = {'agents': [], 'tasks': [], 'inputs': []}
-
-        tools = []
+        framework = default_project.framework
+        design = {
+            'agents': [agent.model_dump() for agent in default_project.agents],
+            'tasks': [task.model_dump() for task in default_project.tasks],
+            'inputs': default_project.inputs,
+        }
+        tools = [tools.model_dump() for tools in default_project.tools]
 
     log.debug(f"project_details: {project_details}" f"framework: {framework}" f"design: {design}")
     insert_template(project_details, framework, design, template_data)
@@ -167,9 +177,10 @@ def run_project(framework: str, path: str = ''):
         print(e)
         sys.exit(1)
 
-    load_dotenv(_path / '.env')  # explicitly load the project's .env file
-    entrypoint = _path / frameworks.get_entrypoint_path(framework)
-    subprocess.run(['python', entrypoint], env=os.environ)
+    load_dotenv(Path.home() / '.env')  # load the user's .env file
+    load_dotenv(_path / '.env', override=True)  # load the project's .env file
+    print("Running your agent...")
+    subprocess.run(['python', 'src/main.py'], env=os.environ)
 
 
 def ask_framework() -> str:
@@ -439,11 +450,12 @@ def insert_template(
         "  Next, run:\n"
         f"    cd {project_metadata.project_slug}\n"
         "    python -m venv .venv\n"
-        "    source .venv/bin/activate\n"
+        "    source .venv/bin/activate\n\n"
+        "  Make sure you have the latest version of poetry installed:\n"
+        "    pip install -U poetry\n\n"
+        "  You'll need to install the project's dependencies with:\n"
         "    poetry install\n\n"
-        "  Add agents and tasks with:\n"
-        "    `agentstack generate agent/task <name>`\n\n"
-        "  Run your agent with:\n"
+        "  Finally, try running your agent with:\n"
         "    agentstack run\n\n"
         "  Run `agentstack quickstart` or `agentstack docs` for next steps.\n"
     )
@@ -466,3 +478,85 @@ def list_tools():
 
     print("\n\n✨ Add a tool with: agentstack tools add <tool_name>")
     print("   https://docs.agentstack.sh/tools/core")
+
+
+def export_template(output_filename: str, path: str = ''):
+    """
+    Export the current project as a template.
+    """
+    _path = Path(path)
+    framework = get_framework(_path)
+
+    try:
+        metadata = ProjectFile(_path)
+    except Exception as e:
+        print(term_color(f"Failed to load project metadata: {e}", 'red'))
+        sys.exit(1)
+
+    # Read all the agents from the project's agents.yaml file
+    agents: list[TemplateConfig.Agent] = []
+    for agent in get_all_agents(_path):
+        agents.append(
+            TemplateConfig.Agent(
+                name=agent.name,
+                role=agent.role,
+                goal=agent.goal,
+                backstory=agent.backstory,
+                model=agent.llm,  # TODO consistent naming (llm -> model)
+            )
+        )
+
+    # Read all the tasks from the project's tasks.yaml file
+    tasks: list[TemplateConfig.Task] = []
+    for task in get_all_tasks(_path):
+        tasks.append(
+            TemplateConfig.Task(
+                name=task.name,
+                description=task.description,
+                expected_output=task.expected_output,
+                agent=task.agent,
+            )
+        )
+
+    # Export all of the configured tools from the project
+    tools_agents: dict[str, list[str]] = {}
+    for agent_name in frameworks.get_agent_names(framework, _path):
+        for tool_name in frameworks.get_agent_tool_names(framework, agent_name, _path):
+            if not tool_name:
+                continue
+            if tool_name not in tools_agents:
+                tools_agents[tool_name] = []
+            tools_agents[tool_name].append(agent_name)
+
+    tools: list[TemplateConfig.Tool] = []
+    for tool_name, agent_names in tools_agents.items():
+        tools.append(
+            TemplateConfig.Tool(
+                name=tool_name,
+                agents=agent_names,
+            )
+        )
+
+    inputs: list[str] = []
+    # TODO extract inputs from project
+    # for input in frameworks.get_input_names():
+    #     inputs.append(input)
+
+    template = TemplateConfig(
+        template_version=1,
+        name=metadata.project_name,
+        description=metadata.project_description,
+        framework=framework,
+        method="sequential",  # TODO this needs to be stored in the project somewhere
+        agents=agents,
+        tasks=tasks,
+        tools=tools,
+        inputs=inputs,
+    )
+
+    try:
+        template.write_to_file(_path / output_filename)
+        print(term_color(f"Template saved to: {_path / output_filename}", 'green'))
+    except Exception as e:
+        print(term_color(f"Failed to write template to file: {e}", 'red'))
+        sys.exit(1)
