@@ -4,7 +4,6 @@ import unittest
 from parameterized import parameterized
 from pathlib import Path
 import shutil
-from agentstack.proj_templates import get_all_template_names
 
 BASE_PATH = Path(__file__).parent
 CLI_ENTRY = [
@@ -32,10 +31,3 @@ class CLIInitTest(unittest.TestCase):
         result = self._run_cli('init', 'test_project')
         self.assertEqual(result.returncode, 0)
         self.assertTrue((self.project_dir / 'test_project').exists())
-
-    @parameterized.expand([(x,) for x in get_all_template_names()])
-    def test_init_command_for_template(self, template_name):
-        """Test the 'init' command to create a project directory with a template."""
-        result = self._run_cli('init', 'test_project', '--template', template_name)
-        self.assertEqual(result.returncode, 0)
-        self.assertTrue((self.project_dir / 'test_project').exists())
